Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Datatx ¶ added in v2.17.0
type Datatx struct {
SourceURI string `json:"srcUri" validate:"required"`
Size uint64 `json:"size" validate:"required"`
}
Datatx contains the parameters for the Datatx protocol.
func (*Datatx) ToOCMProtocol ¶ added in v2.17.0
ToOCMProtocol convert the protocol to a ocm Protocol struct.
type Protocol ¶ added in v2.17.0
type Protocol interface {
// ToOCMProtocol convert the protocol to a ocm Protocol struct
ToOCMProtocol() *ocm.Protocol
}
Protocol represents the way of access the resource in the OCM share.
type Protocols ¶ added in v2.17.0
type Protocols []Protocol
Protocols is the list of protocols.
func (Protocols) MarshalJSON ¶ added in v2.17.0
MarshalJSON implements the Marshaler interface.
func (*Protocols) UnmarshalJSON ¶ added in v2.17.0
UnmarshalJSON implements the Unmarshaler interface.
type WebDAV ¶ added in v2.17.0
type WebDAV struct {
Permissions []string `json:"permissions" validate:"required,dive,required,oneof=read write share"`
URL string `json:"url" validate:"required"`
}
WebDAV contains the parameters for the WebDAV protocol.
func (*WebDAV) ToOCMProtocol ¶ added in v2.17.0
ToOCMProtocol convert the protocol to a ocm Protocol struct.
type Webapp ¶ added in v2.17.0
type Webapp struct {
URITemplate string `json:"uriTemplate" validate:"required"`
ViewMode string `json:"viewMode" validate:"required,dive,required,oneof=view read write"`
}
Webapp contains the parameters for the Webapp protocol.
func (*Webapp) ToOCMProtocol ¶ added in v2.17.0
ToOCMProtocol convert the protocol to a ocm Protocol struct.
Click to show internal directories.
Click to hide internal directories.